@@ -32,14 +32,11 @@ class KActionCollection;
 
 class QWidget;
 
-namespace WebEngineViewer
-{
+namespace WebEngineViewer {
 class ZoomActionMenu;
 }
 
-namespace Akregator
-{
-
+namespace Akregator {
 class ArticleListView;
 class MainWidget;
 class Part;
@@ -60,18 +57,18 @@ public:
     explicit ActionManagerImpl(Part *part, QObject *parent = nullptr);
     virtual ~ActionManagerImpl();
 
-    QAction *action(const QString &name) Q_DECL_OVERRIDE;
-    QWidget *container(const QString &name) Q_DECL_OVERRIDE;
+    QAction *action(const QString &name) override;
+    QWidget *container(const QString &name) override;
 
     void initMainWidget(MainWidget *mainWidget);
     void initArticleListView(ArticleListView *articleList);
     void initSubscriptionListView(SubscriptionListView *subscriptionListView);
     void initTabWidget(TabWidget *tabWidget);
 
-    void setArticleActionsEnabled(bool enabled) Q_DECL_OVERRIDE;
+    void setArticleActionsEnabled(bool enabled) override;
     void setTrayIcon(TrayIcon *trayIcon);
     KActionCollection *actionCollection() const;
-    WebEngineViewer::ZoomActionMenu *zoomActionMenu() const Q_DECL_OVERRIDE;
+    WebEngineViewer::ZoomActionMenu *zoomActionMenu() const override;
     QString quickSearchLineText() const;
 
 public Q_SLOTS:
@@ -91,7 +88,6 @@ private:
     class ActionManagerImplPrivate;
     ActionManagerImplPrivate *d;
 };
-
 } // namespace Akregator
 
 #endif // AKREGATOR_ACTIONMANAGERIMPL_H
