@@ -25,7 +25,7 @@
 
 #include "akregator_part.h"
 #include "akregator_debug.h"
-#include "helper_p.h"
+
 #include "config-akregator.h"
 #include "messageviewer/messageviewersettings.h"
 #include "akregatorconfig.h"
@@ -86,9 +86,7 @@
 #include <QFontDatabase>
 #include <QStandardPaths>
 
-namespace
-{
-
+namespace {
 static QDomDocument createDefaultFeedList()
 {
     QDomDocument doc;
@@ -183,10 +181,9 @@ static QDomDocument createDefaultFeedList()
 }
 }
 
-namespace Akregator
-{
-
-K_PLUGIN_FACTORY(AkregatorFactory, registerPlugin<Part>();)
+namespace Akregator {
+K_PLUGIN_FACTORY(AkregatorFactory, registerPlugin<Part>();
+                 )
 
 static Part *mySelf = nullptr;
 BrowserExtension::BrowserExtension(Part *p, const char *name)
@@ -209,10 +206,9 @@ Part::Part(QWidget *parentWidget, QObject *parent, const QVariantList &)
     , m_shuttingDown(false)
     , m_doCrashSave(false)
     , m_backedUpList(false)
-    , m_mainWidget(0)
-    , m_storage(0)
-    , m_dialog(0)
-
+    , m_mainWidget(nullptr)
+    , m_storage(nullptr)
+    , m_dialog(nullptr)
 {
     mySelf = this;
     //Make sure to initialize settings
@@ -229,6 +225,7 @@ Part::Part(QWidget *parentWidget, QObject *parent, const QVariantList &)
     QDBusConnection::sessionBus().registerObject(QStringLiteral("/Akregator"), this);
 
     const QString path = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/akregator/data/");
+    qDebug() <<"path *****************************************************"<<path;
     QDir().mkpath(path);
     m_standardFeedList = path + QStringLiteral("/feeds.opml");
 
@@ -239,9 +236,9 @@ Part::Part(QWidget *parentWidget, QObject *parent, const QVariantList &)
     }
     loadPlugins(QStringLiteral("storage"));   // FIXME: also unload them!
 
-    m_storage = 0;
+    m_storage = nullptr;
     Backend::StorageFactory *storageFactory = Backend::StorageFactoryRegistry::self()->getFactory(Settings::archiveBackend());
-    if (storageFactory != 0) {
+    if (storageFactory != nullptr) {
         m_storage = storageFactory->createStorage(QStringList());
     }
 
@@ -612,12 +609,12 @@ void Part::exportFile(const QUrl &url)
     if (url.isLocalFile()) {
         const QString fname = url.toLocalFile();
 
-        if (QFileInfo::exists(fname) &&
-                KMessageBox::questionYesNo(m_mainWidget,
-                                           i18n("The file %1 already exists; do you want to overwrite it?", fname),
-                                           i18n("Export"),
-                                           KStandardGuiItem::overwrite(),
-                                           KStandardGuiItem::cancel()) == KMessageBox::No) {
+        if (QFileInfo::exists(fname)
+            && KMessageBox::questionYesNo(m_mainWidget,
+                                          i18n("The file %1 already exists; do you want to overwrite it?", fname),
+                                          i18n("Export"),
+                                          KStandardGuiItem::overwrite(),
+                                          KStandardGuiItem::cancel()) == KMessageBox::No) {
             return;
         }
 
@@ -759,12 +756,12 @@ void Part::initFonts()
         }
         Settings::setMediumFontSize(medfs);
     }
-    QWebEngineSettings::globalSettings()->setFontFamily(QWebEngineSettings::StandardFont, Settings::standardFont());
-    QWebEngineSettings::globalSettings()->setFontFamily(QWebEngineSettings::FixedFont, Settings::fixedFont());
-    QWebEngineSettings::globalSettings()->setFontFamily(QWebEngineSettings::SerifFont, Settings::serifFont());
-    QWebEngineSettings::globalSettings()->setFontFamily(QWebEngineSettings::SansSerifFont, Settings::sansSerifFont());
-    QWebEngineSettings::globalSettings()->setFontSize(QWebEngineSettings::MinimumFontSize, Settings::minimumFontSize());
-    QWebEngineSettings::globalSettings()->setFontSize(QWebEngineSettings::DefaultFontSize, Settings::mediumFontSize());
+    QWebEngineSettings::defaultSettings()->setFontFamily(QWebEngineSettings::StandardFont, Settings::standardFont());
+    QWebEngineSettings::defaultSettings()->setFontFamily(QWebEngineSettings::FixedFont, Settings::fixedFont());
+    QWebEngineSettings::defaultSettings()->setFontFamily(QWebEngineSettings::SerifFont, Settings::serifFont());
+    QWebEngineSettings::defaultSettings()->setFontFamily(QWebEngineSettings::SansSerifFont, Settings::sansSerifFont());
+    QWebEngineSettings::defaultSettings()->setFontSize(QWebEngineSettings::MinimumFontSize, Settings::minimumFontSize());
+    QWebEngineSettings::defaultSettings()->setFontSize(QWebEngineSettings::DefaultFontSize, Settings::mediumFontSize());
 }
 
 bool Part::handleCommandLine(const QStringList &args)
@@ -847,7 +844,8 @@ void Part::autoReadProperties()
 void Part::slotRestoreSession(Akregator::CrashWidget::CrashAction type)
 {
     switch (type) {
-    case Akregator::CrashWidget::RestoreSession: {
+    case Akregator::CrashWidget::RestoreSession:
+    {
         KConfig config(QStringLiteral("crashed"), KConfig::SimpleConfig,
                        QStandardPaths::AppDataLocation);
         KConfigGroup configGroup(&config, "Part");
@@ -863,6 +861,5 @@ void Part::slotRestoreSession(Akregator::CrashWidget::CrashAction type)
     }
     m_doCrashSave = true;
 }
-
 } // namespace Akregator
 #include "akregator_part.moc"
